.. _api_reference:

===============
API Reference
===============

.. automodule:: QuadratiK.kernel_test

.. currentmodule:: QuadratiK.kernel_test

Kernel Tests
==============

.. autosummary::
   :toctree: generated/

   KernelTest
   select_h

.. automodule:: QuadratiK.poisson_kernel_test

.. currentmodule:: QuadratiK.poisson_kernel_test

Poisson Kernel Test
=====================

.. autosummary::
   :toctree: generated/

   PoissonKernelTest


.. automodule:: QuadratiK.spherical_clustering

.. currentmodule:: QuadratiK.spherical_clustering

Spherical Clustering
======================

.. autosummary::
   :toctree: generated/

   PKBC
   PKBD


.. automodule:: QuadratiK.ui

.. currentmodule:: QuadratiK.ui

User Interface
==================

.. autosummary::
   :toctree: generated/

   UI

.. automodule:: QuadratiK.datasets

.. currentmodule:: QuadratiK.datasets

Datasets
==============

.. autosummary::
   :toctree: generated/

   load_wireless_data
   load_wisconsin_breast_cancer_data
   load_wine_data

.. automodule:: QuadratiK.tools

.. currentmodule:: QuadratiK.tools

Tools
===========

.. autosummary::
   :toctree: generated/

   sample_hypersphere
   stats
   qq_plot
   sphere3d
   plot_clusters_2d
   


   


